@@ -2,12 +2,13 @@ use strict;
 use warnings;
 
 package OD::Prometheus::Client;
-$OD::Prometheus::Client::VERSION = '0.003';
+$OD::Prometheus::Client::VERSION = '0.004';
 use v5.24;
 use Moose;
 use LWP::UserAgent;
 use Data::Printer;
 use OD::Prometheus::Metric;
+use OD::Prometheus::Set;
 
 =head1 NAME
 
@@ -15,7 +16,7 @@ OD::Prometheus::Client - Client library to talk to Prometheus nodes
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =cut
 
@@ -85,7 +86,7 @@ sub get {
 	my $self = shift // die 'incorrect call';
 	my $res = $self->ua->request($self->request);
 	if ($res->is_success) {
-		my @ret = ();
+		my $ret = OD::Prometheus::Set->new;
 		my @comments = ();
 		for my $line ( split("\n",$res->decoded_content) ) {
 			if( $line =~ /^#/ ){
@@ -95,11 +96,11 @@ sub get {
 				next
 			}
 			else {
-				push @ret,OD::Prometheus::Metric->new( line => $line, comments => \@comments );
+				$ret->push( OD::Prometheus::Metric->new( line => $line, comments => \@comments ) );
 				@comments = ();
 			}
 		}
-		return \@ret
+		return $ret
 	}
 	else {
 		die $res->status_line
